def outlier(n):
    import numpy as np
    data = n
    
    q1= np.percentile(data,25)
    q2= np.percentile(data,50)
    q3= np.percentile(data,75)
    
    iqr = q3 - q1
    
    ub = q3 + 1.5 * iqr
    lb = q1 - 1.5 * iqr
    
    upper_value_index = np.where((data > q3) & (data < ub))
    lower_value_index = np.where((data > lb) & (data < q1))
    
    up_value = max(data[upper_value_index[0]])
    low_value = min(data[lower_value_index[0]])
    
	
    return (low_value, up_value)



from setuptools import setup, find_packages

setup(
    name="vijay_lib",               # Name of your library
    version="0.4.0",                # Initial version
    author="Vijayraje Jadhav",      # Your name
    author_email="jadhavvijayraje1137@gmail.com",  # Your email
    description="A library to calculate upper and lower IQR values.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/vijay_lib",  # Replace with your GitHub repo
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=["numpy"],  # External dependencies
)

